@@ -129,7 +129,7 @@ class QsConfig:
     },
     "default_proxy": "user:password@ip:port or ip:port",
     "default_pip": "pip3",
-    "force_show_img": false,
+    "force_show_img": false
   },
   "API_settings": {
     "rmbg": "GET: https://www.remove.bg",
@@ -210,26 +210,3 @@ class QsConfig:
     def apiUpdate(self, key: str, value: str):
         self.config['API_settings'][key] = value
         return self.update()
-
-
-class QsCache:
-    """
-    qs存储在~/.qs_cache的缓存
-    """
-    import os
-    import pickle
-
-    def __init__(self, cachePath: str):
-        self.path = cachePath + dir_char
-        if not QsCache.os.path.exists(cachePath):
-            QsCache.os.mkdir(cachePath)
-
-    def get(self, key: str):
-        if not QsCache.os.path.exists(self.path + key):
-            return None
-        with open(self.path + key, 'rb') as f:
-            return QsCache.pickle.loads(f.read())
-
-    def set(self, key: str, value):
-        with open(self.path + key, 'wb') as f:
-            QsCache.pickle.dump(value, f)
